@@ -5,6 +5,6 @@ if not settings.configured:
     settings.configure()
 django.setup()
 
-VERSION = '2.2.0'
+VERSION = '2.4.0'
 
-from .core import load  # NOQA
+from flex.core import load  # NOQA
