@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 
 TYPE_MESSAGES = {
+    'unknown': 'Unknown type: {0}',
     'invalid': "Got value `{0}` of type `{1}`.  Value must be of type(s): `{2}`",
     'invalid_header_type': (
         "Invalid type for header: `{0}`.  Must be one of 'string', 'number', "
@@ -56,6 +57,21 @@ PATTERN_MESSAGES = {
 }
 
 
+MIN_PROPERTIES_MESSAGES = {
+    'invalid': "Object must have more than {0} properties.  It had {1}",
+}
+
+
+MAX_PROPERTIES_MESSAGES = {
+    'invalid': "Object must have less than {0} properties.  It had {1}",
+}
+
+
+ITEMS_MESSAGES = {
+    'invalid_type': '`items` must be a reference, a schema, or an array of schemas.',
+}
+
+
 REQUEST_MESSAGES = {
     'unknown_path': 'Request path did not match any of the known api paths.',
     'invalid_method': (
@@ -82,6 +98,13 @@ PATH_MESSAGES = {
 }
 
 
+UNKNOWN_REFERENCE_MESSAGES = {
+    'security': "Unknown SecurityScheme reference `{0}`",
+    'parameter': "Unknown Parameter reference `{0}`",
+    'definition': 'Unknown definition reference `{0}`',
+}
+
+
 MESSAGES = {
     'type': TYPE_MESSAGES,
     'format': FORMAT_MESSAGES,
@@ -91,10 +114,14 @@ MESSAGES = {
     'maximum': MINIMUM_AND_MAXIMUM_MESSAGES,
     'min_items': MIN_ITEMS_MESSAGES,
     'max_items': MAX_ITEMS_MESSAGES,
+    'min_properties': MIN_PROPERTIES_MESSAGES,
+    'max_properties': MAX_PROPERTIES_MESSAGES,
     'unique_items': UNIQUE_ITEMS_MESSAGES,
     'enum': ENUM_MESSAGES,
     'pattern': PATTERN_MESSAGES,
+    'items': ITEMS_MESSAGES,
     'request': REQUEST_MESSAGES,
     'response': RESPONSE_MESSAGES,
     'path': PATH_MESSAGES,
+    'unknown_reference': UNKNOWN_REFERENCE_MESSAGES,
 }
