@@ -1,13 +1,11 @@
 import functools
 import operator
 
-from django.core.exceptions import ValidationError
-
+from flex.exceptions import ValidationError
 from flex.utils import chain_reduce_partial
 from flex.context_managers import ErrorCollection
 from flex.http import (
     Request,
-    Response,
 )
 from flex.constants import (
     QUERY,
@@ -26,7 +24,10 @@ from flex.validation.parameter import (
 from flex.validation.header import (
     construct_header_validators,
 )
-from flex.validation.common import validate_object
+from flex.validation.common import (
+    validate_object,
+    generate_value_processor,
+)
 
 
 def validate_operation(request, validators, inner=False):
@@ -35,7 +36,7 @@ def validate_operation(request, validators, inner=False):
             try:
                 validator(request)
             except ValidationError as err:
-                errors[key].extend(list(err.messages))
+                errors[key].add_error(err.detail)
 
 
 def validate_request_content_type(request, content_types):
@@ -53,27 +54,7 @@ def generate_request_content_type_validator(consumes, **kwargs):
         validate_request_content_type,
         content_types=consumes,
     )
-    return chain_reduce_partial(
-        operator.attrgetter('request'),
-        validator,
-    )
-
-
-def validate_response_content_type(response, content_types):
-    assert isinstance(response, Response)  # TODO: remove this sanity check
-    if response.content_type not in content_types:
-        raise ValidationError(
-            'Invalid content type `{0}`.  Must be one of `{1}`.'.format(
-                response.content_type, content_types,
-            ),
-        )
-
-
-def generate_response_content_type_validator(produces, **kwargs):
-    return functools.partial(
-        validate_response_content_type,
-        content_types=produces,
-    )
+    return validator
 
 
 def validate_request_parameters(request, validators):
@@ -83,7 +64,7 @@ def validate_request_parameters(request, validators):
             try:
                 fn(request)
             except ValidationError as err:
-                errors[key].extend(list(err.messages))
+                errors[key].add_error(err.detail)
 
 
 def generate_path_parameters_validator(api_path, path_parameters, context):
@@ -116,6 +97,10 @@ def generate_query_parameters_validator(query_parameters, context):
 def generate_header_validator(headers, context, **kwargs):
     validators = {}
     for header_definition in headers:
+        header_processor = generate_value_processor(
+            context=context,
+            **header_definition
+        )
         header_validator = functools.partial(
             validate_object,
             validators=construct_header_validators(header_definition, context=context),
@@ -123,6 +108,7 @@ def generate_header_validator(headers, context, **kwargs):
         )
         validators[header_definition['name']] = chain_reduce_partial(
             operator.methodcaller('get', header_definition['name'], EMPTY),
+            header_processor,
             header_validator,
         )
     return chain_reduce_partial(
@@ -137,7 +123,7 @@ def generate_parameters_validator(api_path, path_definition, parameters, context
 
     - request.path against the path parameters.
     - request.query against the query parameters.
-    - TODO: request.headers against the header parameters.
+    - request.headers against the header parameters.
     - TODO: request.body against the body parameters.
     - TODO: request.formData against any form data.
     """
@@ -164,45 +150,34 @@ def generate_parameters_validator(api_path, path_definition, parameters, context
     in_header_parameters = filter_parameters(all_parameters, in_=HEADER)
     validators['headers'] = generate_header_validator(in_header_parameters, context)
 
-    return chain_reduce_partial(
-        operator.attrgetter('request'),
-        functools.partial(validate_request_parameters, validators=validators),
-    )
+    return functools.partial(validate_request_parameters, validators=validators)
 
 
 validator_mapping = {
     'consumes': generate_request_content_type_validator,
-    'produces': generate_response_content_type_validator,
     'parameters': generate_parameters_validator,
     'headers': generate_header_validator,
 }
 
 
-def construct_operation_validators(api_path, path_definition, operation, context):
+def construct_operation_validators(api_path, path_definition, operation_definition, context):
+    """
+    - consumes (did the request conform to the content types this api consumes)
+    - produces (did the response conform to the content types this endpoint produces)
+    - parameters (did the parameters of this request validate)
+      TODO: move path parameter validation to here, because each operation
+            can override any of the path level parameters.
+    - schemes (was the request scheme correct)
+    - security: TODO since security isn't yet implemented.
+    """
     validators = {}
 
-    # - consumes (did the request conform to the content types this api consumes)
-    # - produces (did the response conform to the content types this endpoint produces)
-    # - parameters (did the parameters of this request validate)
-    #   TODO: move path parameter validation to here, because each operation
-    #         can override any of the path level parameters.
-    # - schemes (was the request scheme correct)
-    # - security: TODO since security isn't yet implemented.
-    try:
-        operation_definition = path_definition[operation]
-    except KeyError:
-        raise ValidationError(
-            'Unknown operation `{0}`.  Must be one of `{1}`'.format(
-                operation, path_definition.keys(),
-            ),
-        )
-
     # sanity check
     assert 'context' not in operation_definition
     assert 'api_path' not in operation_definition
     assert 'path_definition' not in operation_definition
 
-    for key, value in operation_definition.items():
+    for key in operation_definition.keys():
         if key not in validator_mapping:
             # TODO: is this the right thing to do?
             continue
@@ -216,8 +191,6 @@ def construct_operation_validators(api_path, path_definition, operation, context
     # Global defaults
     if 'consumes' in context and 'consumes' not in validators:
         validators['consumes'] = validator_mapping['consumes'](**context)
-    if 'produces' in context and 'produces' not in validators:
-        validators['produces'] = validator_mapping['produces'](**context)
     if 'parameters' in path_definition and 'parameters' not in validators:
         validators['parameters'] = validator_mapping['parameters'](
             context=context,
